@@ -1,10 +1,10 @@
-from typing import Any, List, Optional, Union
+from typing import Any, Callable, List, Optional, Union
 
 from easytxt.text import to_list
 from pyquery import PyQuery
 
+from easydata.config.loader import ConfigLoader
 from easydata.data import DataBag
-from easydata.default import Config
 from easydata.parsers.base import Base
 from easydata.processors.base import BaseProcessor
 
@@ -70,7 +70,7 @@ def pq_extract_value_items(
 
 def init_processors_config(
     processors: list,
-    config: Config,
+    config: ConfigLoader,
 ):
 
     for processor in processors:
@@ -92,22 +92,30 @@ def apply_processors(
     return value
 
 
-def extract_item_attr_names_from_cls(cls, preserve_item_prefix=False):
+def extract_attr_names_from_obj(obj: object, attr_prefix: str):
+
     attr_names = []
 
-    for attr_name in dir(cls):
-        if attr_name.startswith("item_"):
-            if preserve_item_prefix:
-                attr_names.append(attr_name)
-            else:
-                attr_names.append(attr_name.lstrip("item").lstrip("_"))
+    for attr_name in dir(obj):
+        if attr_name.startswith(attr_prefix + "_"):
+            attr_names.append(attr_name)
 
     return attr_names
 
 
-def iter_item_attr_data_from_cls(cls):
-    for attr_name in extract_item_attr_names_from_cls(cls, True):
-        yield attr_name, getattr(cls, attr_name)
+def iter_attr_data_from_obj(
+    obj: object, attr_prefix: str, preserve_prefix: bool = False
+):
+
+    attr_name = extract_attr_names_from_obj(obj=obj, attr_prefix=attr_prefix)
+
+    for attr_name in attr_name:
+        attr_value = getattr(obj, attr_name)
+
+        if not preserve_prefix:
+            attr_name = attr_name.lstrip(attr_prefix).lstrip("_")
+
+        yield attr_name, attr_value
 
 
 def make_variant_data_copy(
@@ -155,6 +163,28 @@ def multiply_list_values(
     return new_all_list_values
 
 
+def filter_list_by_bool_callable(
+    list_values: List[Any],
+    data: Any,
+    callable_param: Callable,
+):
+
+    filtered_list_values = []
+
+    for value in list_values:
+        ignore: bool = callable_param(value, data)
+
+        if not isinstance(ignore, bool):
+            raise TypeError("Allow callable must return bool.")
+
+        if ignore is False:
+            continue
+
+        filtered_list_values.append(value)
+
+    return filtered_list_values
+
+
 def validate_parser(
     parser: Base,
 ):
