@@ -1,5 +1,4 @@
-from easydata import parsers
-from easydata.models import ItemModel
+from easydata import ItemModel, parsers
 from easydata.processors import DataJsonToDictProcessor, ItemDiscountProcessor
 from easydata.queries import jp, pq
 
@@ -56,3 +55,17 @@ class ProductSimpleWithProcessItemModel(ItemModel):
         item["final_sale"] = bool(item["discount"])
 
         return item
+
+
+class PricingBlockModel(ItemModel):
+    item_price = parsers.PriceFloat(pq("#price::text"))
+
+    item_sale_price = parsers.PriceFloat(pq("#sale-price::text"))
+
+    items_processors = [("discount", ItemDiscountProcessor())]
+
+
+class SettingsBlockModel(ItemModel):
+    item_calling_code = 44
+
+    item_country = "UK"
